Index: tests/compiler/dart2js/proxy_test.dart |
diff --git a/tests/compiler/dart2js/least_upper_bound_language_test.dart b/tests/compiler/dart2js/proxy_test.dart |
similarity index 73% |
copy from tests/compiler/dart2js/least_upper_bound_language_test.dart |
copy to tests/compiler/dart2js/proxy_test.dart |
index f75c32c63f4af501991d1185ef62bdccde7e0beb..c558350c12097c8ffd881f91fbccdb6c5ca48645 100644 |
--- a/tests/compiler/dart2js/least_upper_bound_language_test.dart |
+++ b/tests/compiler/dart2js/proxy_test.dart |
@@ -2,9 +2,9 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
// Test that dart2js produces the expected static type warnings for least upper |
// bound language tests. This ensures that the analyzer and dart2js agrees |
// on these tests. |
import 'warnings_checker.dart'; |
@@ -13,8 +13,8 @@ import 'warnings_checker.dart'; |
/// can contain a list of line numbers for keys 'missing' and 'unexpected' for |
/// the warnings of each category. |
const Map<String, dynamic> TESTS = const { |
- 'language/least_upper_bound_test.dart': null, |
- 'language/least_upper_bound_expansive_test.dart': null, |
+ 'language/proxy_test.dart': null, |
+ 'language/proxy2_test.dart': null, |
}; |
void main() { |
@@ -2,9 +2,9 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-// Test that dart2js produces the expected static type warnings for least upper |
-// bound language tests. This ensures that the analyzer and dart2js agrees |
-// on these tests. |
+// Test that dart2js produces the expected static type warnings for proxy |
+// language tests. This ensures that the analyzer and dart2js agrees on these |
+// tests. |
import 'warnings_checker.dart'; |